@@ -14,10 +14,10 @@
 #include "taia.h"
 #include "wait.h"
 
-#define USAGE " [-v] [-w sec] action service ..."
-#define USAGELSB " [-w sec] action"
+#define USAGE " [-v] [-w sec] command service ..."
+#define USAGELSB " [-w sec] command"
 
-#define VERSION "$Id: sv.c,v 1.9 2005/08/24 20:11:40 pape Exp $"
+#define VERSION "$Id: sv.c,v 1.11 2006/03/04 14:14:49 pape Exp $"
 
 #define FATAL   "fatal: "
 #define FAIL    "fail: "
@@ -217,6 +217,7 @@ int check(char *a) {
   case 'x': return(0);
   case 'u': if (!pid) return(0); if (!checkscript()) return(0); break;
   case 'd': if (pid) return(0); break;
+  case 'c': if (pid) if (!checkscript()) return(0); break;
   case 't':
     if (!pid && svstatus[17] == 'd') break;
     tai_unpack(svstatus, &tstatus);
@@ -268,7 +269,7 @@ int main(int argc, char **argv) {
     case 'w': scan_ulong(optarg, &wait);
     case 'v': verbose =1; break;
     case 'V':
-      strerr_warn1("$Id: sv.c,v 1.9 2005/08/24 20:11:40 pape Exp $", 0);
+      strerr_warn1("$Id: sv.c,v 1.11 2006/03/04 14:14:49 pape Exp $", 0);
     case '?': usage();
     }
   }
@@ -292,7 +293,9 @@ int main(int argc, char **argv) {
     acts ="d"; kll =1; cbk =&check; break;
   case 'T':
     acts ="tc"; kll =1; cbk =&check; break;
-  case 'u': case 'd': case 'o': case 't': case 'p': case 'c': case 'h':
+  case 'c':
+    if (!str_diff(action, "check")) { act =0; acts ="c"; cbk =&check; break; }
+  case 'u': case 'd': case 'o': case 't': case 'p': case 'h':
   case 'a': case 'i': case 'k': case 'q': case '1': case '2':
     action[1] =0; acts =action; break;
   case 's':
@@ -330,7 +333,7 @@ int main(int argc, char **argv) {
         fail("unable to change to service directory");
         *service =0;
       }
-    if (*service) if (act(acts) == -1) *service =0;
+    if (*service) if (act && (act(acts) == -1)) *service =0;
     if (fchdir(curdir) == -1) fatal("unable to change to original directory");
     service++;
   }
